"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prettierDifferences = void 0;
const path = require("path");
const chalk = require("chalk");
const prettier = require("prettier");
const prettier_linter_helpers_1 = require("prettier-linter-helpers");
const report_1 = require("./report");
const { INSERT, DELETE, REPLACE } = prettier_linter_helpers_1.generateDifferences;
const prettierDifferences = ({ context, source, options, offset = 0, }) => {
    let prettierSource;
    try {
        prettierSource = prettier.format(source, options);
    }
    catch (err) {
        if (err.message.startsWith('No parser could be inferred for file')) {
            console.warn(chalk.yellow('warning'), '[prettier-vue]', `No parser could be inferred for "${path.extname(options.filepath || '')}" format`);
            return;
        }
        if (!(err instanceof SyntaxError)) {
            throw err;
        }
        let message = `Parsing error: ${err.message}`;
        const error = err;
        if (error.codeFrame) {
            message = message.replace(`\n${error.codeFrame}`, '');
        }
        if (error.loc) {
            message = message.replace(/ \(\d+:\d+\)$/, '');
        }
        context.report({ message, loc: error.loc });
        return;
    }
    if (source !== prettierSource) {
        const differences = prettier_linter_helpers_1.generateDifferences(source, prettierSource);
        differences.forEach((difference) => {
            switch (difference.operation) {
                case INSERT:
                    report_1.reportInsert(context, difference.offset + offset, difference.insertText);
                    break;
                case DELETE:
                    report_1.reportDelete(context, difference.offset + offset, difference.deleteText);
                    break;
                case REPLACE:
                    report_1.reportReplace(context, difference.offset + offset, difference.deleteText, difference.insertText);
                    break;
                default:
            }
        });
    }
};
exports.prettierDifferences = prettierDifferences;
